@@ -41,15 +41,16 @@ formant.read <- function(fileNameFormant, encoding = "UTF-8") {
     if (!isString(encoding)) {
         stop("Invalid 'encoding' parameter.")
     }
+    enc <- encoding
 
     if (encoding == "auto") {
-        encoding <- detectEncoding(fileNameFormant)
+        enc <- detectEncoding(fileNameFormant)
     }
 
-    if (encoding == "UTF-8") {
+    if (enc == "UTF-8") {
         flines <- readr::read_lines(fileNameFormant, locale = readr::locale(encoding = "UTF-8"))  # Does not support UTF-16 at this point :-(
     } else {
-        fid <- file(fileNameFormant, open = "r", encoding = encoding)
+        fid <- file(fileNameFormant, open = "r", encoding = enc)
         flines <- readLines(fid)   # does not work with tests/testthat/utf8.TextGrid  :-(
         close(fid)
     }
@@ -60,6 +61,12 @@ formant.read <- function(fileNameFormant, encoding = "UTF-8") {
         stop("Empty file.")
     }
 
+    if (encoding == "UTF-8" & flines[1] != 'File type = "ooTextFile"') {
+        warning('Not an UTF-8 Formant format, trying encoding = "auto"...')
+        x <- formant.read(fileNameFormant, encoding = "auto")
+        return(x)
+    }
+
     formant_ind <- formant.read_lines(flines)
     class(formant_ind[[1]])["type"] <- "Formant 2"
     class(formant_ind[[1]])["name"] <- basename(fileNameFormant)
