@@ -24,15 +24,16 @@ pt.read <- function(fileNamePitchTier, encoding = "UTF-8") {
     if (!isString(encoding)) {
         stop("Invalid 'encoding' parameter.")
     }
+    enc <- encoding
 
     if (encoding == "auto") {
-        encoding <- detectEncoding(fileNamePitchTier)
+        enc <- detectEncoding(fileNamePitchTier)
     }
 
-    if (encoding == "UTF-8") {
+    if (enc == "UTF-8") {
         flines <- readr::read_lines(fileNamePitchTier, locale = readr::locale(encoding = "UTF-8"))  # Does not support UTF-16 at this point :-(
     } else {
-        fid <- file(fileNamePitchTier, open = "r", encoding = encoding)
+        fid <- file(fileNamePitchTier, open = "r", encoding = enc)
         flines <- readLines(fid)   # does not work with tests/testthat/utf8.TextGrid  :-(
         close(fid)
     }
@@ -44,6 +45,18 @@ pt.read <- function(fileNamePitchTier, encoding = "UTF-8") {
         stop("Empty file.")
     }
 
+    if (encoding == "UTF-8") {
+        if (flines[1] != 'File type = "ooTextFile"'  &  flines[1] != '"ooTextFile"') {
+            # maybe headerlessSpreadSheet ?
+            spl <- strsplit(flines[1], "\t")
+            if (length(spl[[1]]) != 2) {
+                warning('Not an UTF-8 PitchTier format, trying encoding = "auto"...')
+                x <- pt.read(fileNamePitchTier, encoding = "auto")
+                return(x)
+            }
+        }
+    }
+
     pt_ind <- pt.read_lines(flines)
     class(pt_ind[[1]])["type"] <- "PitchTier"
     class(pt_ind[[1]])["name"] <- basename(fileNamePitchTier)
@@ -350,7 +363,7 @@ pt.plot <- function(pt, group = "") {
 #' pt.plot(pt2)
 #' }
 pt.interpolate <- function(pt, t) {
-    if (class(t) != "numeric"  &  class(t) != "integer") {
+    if (!("numeric" %in% class(t)) &  !("integer" %in% class(t))) {
         stop("t must be numeric vector")
     }
 
@@ -523,7 +536,7 @@ pt.legendre <- function(pt, npoints = 1000, npolynomials = 4) {
 #' lines(ptLeg$t, ptLeg$f, col = "blue")
 #' }
 pt.legendreSynth <- function(c, npoints = 1000) {
-    if (class(c) != "numeric"  &  class(c) != "integer") {
+    if (!("numeric" %in% class(c)) &  !("integer" %in% class(c))) {
         stop("c must be numeric vector")
     }
 
